Learn R Programming

survELtest (version 2.0.1)

hazardcross_Weibull: Simulated survival data with crossing hazard functions from the Weibull distribution

Description

The data frame hazardcross_Weibull is obtained as follows. The survival time is generated from the Weibull model displayed as the solid and dashed lines in the right panel of Figure 1 in Chang and McKeague (2019). The censoring distributions (the same in each arm) is specified to be uniform with administrative censoring at \(t = 10\), and a censoring rate of \(25\%\) in the first group.

Usage

hazardcross_Weibull

Arguments

Format

The hazardcross_Weibull is a data frame with 100 observations of 3 variables, and has the following columns:

  • time the observed times to first remission and censoring times

  • censor the censoring indicator

  • group the grouping variable

References

H. Chang, I.W. McKeague, "Nonparametric testing for multiple survival functions with non-inferiority margins," Annals of Statistics, Vol. 47, No. 1, pp. 205-232, (2019).

See Also

nocrossings, ptwiseELtest, supELtest