Learn R Programming

survELtest (version 2.0.1)

summary.nocrossings: Summary function for nocrossings object

Description

Returns the decision for rejection of the null hypothesis that there are crossings or alternative orderings among the survival functions.

Usage

# S3 method for nocrossings
summary(object, digits = max(3L, getOption("digits") - 3L), quiet = FALSE, ...)

Arguments

object

the result of a call to the nocrossings function

digits

significant digits to print, the default value is max(3L, getOption("digits") - 3L)

quiet

a logical indicating whether to reduce the amount of output or not, the default value is FALSE

...

for future method

Value

summary.nocrossings returns a list with following components:

  • call the statement used to create the nocrossings object

  • decision \(1\) for rejection of the null hypothesis that there are crossings or alternative orderings among the survival functions, and \(0\) otherwise

See Also

hepatitis, nocrossings, print.nocrossings

Examples

Run this code
# NOT RUN {
library(survELtest)
result = nocrossings(survival::Surv(hepatitis$time, hepatitis$censor)~
          hepatitis$group, sided = 1)
summary(result)

## OUTPUT:
## Call:
## nocrossings(formula = survival::Surv(hepatitis$time, hepatitis$censor) ~ 
##     hepatitis$group, sided = 1)
## 
## Decision = 1
# }

Run the code above in your browser using DataLab