Learn R Programming

survELtest (version 2.0.1)

threearm: Time to first remission data

Description

The data frame threearm is obtained by resampling from perturbed time-to-remission from patients in a three-arm randomized clinical trial for the treatment of major depression. See nocrossings, ptwiseELtest and supELtest for the application.

Usage

threearm

Arguments

Format

The threearm is a data frame with 664 observations of 3 variables, and has the following columns:

  • time the observed times to first remission and censoring times

  • censor the censoring indicator

  • group the grouping variable

See Also

nocrossings, ptwiseELtest, supELtest